# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector_v2.models.course_structure import CourseStructure

class TestCourseStructure(unittest.TestCase):
    """CourseStructure unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseStructure:
        """Test CourseStructure
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseStructure`
        """
        model = CourseStructure()
        if include_optional:
            return CourseStructure(
                course_id = 56,
                version = 's_0',
                modules = [
                    access_server_connector_v2.models.module_structure.ModuleStructure(
                        module_id = 56, 
                        is_published = True, 
                        default_unlock = null, 
                        lessons = [
                            access_server_connector_v2.models.lesson_structure.LessonStructure(
                                lesson_id = 56, 
                                is_published = True, 
                                default_unlock = null, )
                            ], )
                    ]
            )
        else:
            return CourseStructure(
                course_id = 56,
        )
        """

    def testCourseStructure(self):
        """Test CourseStructure"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
