# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from access_server_connector_v2.models.event_order import EventOrder
from access_server_connector_v2.models.event_product import EventProduct
from access_server_connector_v2.models.event_subscription import EventSubscription
from access_server_connector_v2.models.reason_kind import ReasonKind
from access_server_connector_v2.models.reason_status import ReasonStatus
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class AccessOrderEvent(BaseModel):
    """
    AccessOrderEvent
    """ # noqa: E501
    event_id: StrictStr
    occurred_at: StrictInt
    portal_id: StrictInt
    member_id: StrictInt
    reason_kind: Optional[ReasonKind] = None
    product: Optional[EventProduct] = None
    access_package_ids: Optional[List[StrictInt]] = None
    order: Optional[EventOrder] = None
    status: ReasonStatus
    status_reason: Optional[StrictStr] = None
    subscription: Optional[EventSubscription] = None
    __properties: ClassVar[List[str]] = ["event_id", "occurred_at", "portal_id", "member_id", "reason_kind", "product", "access_package_ids", "order", "status", "status_reason", "subscription"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccessOrderEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of product
        if self.product:
            _dict['product'] = self.product.to_dict()
        # override the default output from pydantic by calling `to_dict()` of order
        if self.order:
            _dict['order'] = self.order.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscription
        if self.subscription:
            _dict['subscription'] = self.subscription.to_dict()
        # set to None if product (nullable) is None
        # and model_fields_set contains the field
        if self.product is None and "product" in self.model_fields_set:
            _dict['product'] = None

        # set to None if access_package_ids (nullable) is None
        # and model_fields_set contains the field
        if self.access_package_ids is None and "access_package_ids" in self.model_fields_set:
            _dict['access_package_ids'] = None

        # set to None if order (nullable) is None
        # and model_fields_set contains the field
        if self.order is None and "order" in self.model_fields_set:
            _dict['order'] = None

        # set to None if status_reason (nullable) is None
        # and model_fields_set contains the field
        if self.status_reason is None and "status_reason" in self.model_fields_set:
            _dict['status_reason'] = None

        # set to None if subscription (nullable) is None
        # and model_fields_set contains the field
        if self.subscription is None and "subscription" in self.model_fields_set:
            _dict['subscription'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccessOrderEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "event_id": obj.get("event_id"),
            "occurred_at": obj.get("occurred_at"),
            "portal_id": obj.get("portal_id"),
            "member_id": obj.get("member_id"),
            "reason_kind": obj.get("reason_kind"),
            "product": EventProduct.from_dict(obj["product"]) if obj.get("product") is not None else None,
            "access_package_ids": obj.get("access_package_ids"),
            "order": EventOrder.from_dict(obj["order"]) if obj.get("order") is not None else None,
            "status": obj.get("status"),
            "status_reason": obj.get("status_reason"),
            "subscription": EventSubscription.from_dict(obj["subscription"]) if obj.get("subscription") is not None else None
        })
        return _obj


